==> jc-1.4.0.tar.gz: javax/imageio/stream/FileCacheImageInputStream.h <==
// public class javax.imageio.stream.FileCacheImageInputStream

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e71a54dddda63520 javax_imageio_stream_FileCacheImageInputStream
// @dep_class 911ef4842ed4a340 javax_imageio_stream_ImageInputStreamImpl

// header file dependencies
// @dep_header javax_imageio_stream_ImageInputStreamImpl

#include "javax/imageio/stream/ImageInputStreamImpl.h"

#ifndef _JC_javax_imageio_stream_FileCacheImageInputStream_H_
#define _JC_javax_imageio_stream_FileCacheImageInputStream_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_stream_FileCacheImageInputStream$sub_refs	_jc_javax_imageio_stream_FileCacheImageInputStream$sub_refs;
typedef struct _jc_javax_imageio_stream_FileCacheImageInputStream$sub_nonrefs	_jc_javax_imageio_stream_FileCacheImageInputStream$sub_nonrefs;
typedef struct _jc_javax_imageio_stream_FileCacheImageInputStream$refs	_jc_javax_imageio_stream_FileCacheImageInputStream$refs;
typedef struct _jc_javax_imageio_stream_FileCacheImageInputStream$nonrefs	_jc_javax_imageio_stream_FileCacheImageInputStream$nonrefs;
typedef struct _jc_javax_imageio_stream_FileCacheImageInputStream$object	_jc_javax_imageio_stream_FileCacheImageInputStream$object;

typedef const struct _jc_javax_imageio_stream_FileCacheImageInputStream$vmethods	_jc_javax_imageio_stream_FileCacheImageInputStream$vmethods;
typedef const struct _jc_javax_imageio_stream_FileCacheImageInputStream$vtable	_jc_javax_imageio_stream_FileCacheImageInputStream$vtable;
typedef const struct _jc_javax_imageio_stream_FileCacheImageInputStream$vtype	_jc_javax_imageio_stream_FileCacheImageInputStream$vtype;

// Constructors
extern void _jc_javax_imageio_stream_FileCacheImageInputStream$method$_init$f95b7927140e2662(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_java_io_File$object *);

// Virtual methods
extern void _jc_javax_imageio_stream_FileCacheImageInputStream$method$checkStreamClosed$e73f603b18f58e4c(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *);
extern void _jc_javax_imageio_stream_FileCacheImageInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *);
extern jboolean _jc_javax_imageio_stream_FileCacheImageInputStream$method$isCached$7eabc2d936c77133(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *);
extern jboolean _jc_javax_imageio_stream_FileCacheImageInputStream$method$isCachedFile$ed19c4c24a1815db(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *);
extern jboolean _jc_javax_imageio_stream_FileCacheImageInputStream$method$isCachedMemory$53b63747781a10df(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *);
extern jint _jc_javax_imageio_stream_FileCacheImageInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *);
extern jint _jc_javax_imageio_stream_FileCacheImageInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_stream_FileCacheImageInputStream$method_info$checkStreamClosed$e73f603b18f58e4c;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageInputStream$method_info$isCached$7eabc2d936c77133;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageInputStream$method_info$isCachedFile$ed19c4c24a1815db;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageInputStream$method_info$isCachedMemory$53b63747781a10df;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_javax_imageio_stream_FileCacheImageInputStream$vmethods {
	void	(*checkStreamClosed$e73f603b18f58e4c)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *);
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *);
	jboolean	(*isCached$7eabc2d936c77133)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *);
	jboolean	(*isCachedFile$ed19c4c24a1815db)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *);
	jboolean	(*isCachedMemory$53b63747781a10df)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_javax_imageio_stream_FileCacheImageInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_stream_ImageInputStreamImpl$vmethods	javax_imageio_stream_ImageInputStreamImpl;
	_jc_javax_imageio_stream_FileCacheImageInputStream$vmethods	javax_imageio_stream_FileCacheImageInputStream;
};

// Vtype
struct _jc_javax_imageio_stream_FileCacheImageInputStream$vtype {
	_jc_type			type;
	_jc_javax_imageio_stream_FileCacheImageInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileCacheImageInputStream$sub_refs {
	struct _jc_java_io_InputStream$object	*stream;
	struct _jc_java_io_File$object	*cacheDir;
};

// Reference instance fields (object)
struct _jc_javax_imageio_stream_FileCacheImageInputStream$refs {
    _jc_javax_imageio_stream_FileCacheImageInputStream$sub_refs	javax_imageio_stream_FileCacheImageInputStream;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_refs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileCacheImageInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_stream_FileCacheImageInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_javax_imageio_stream_FileCacheImageInputStream$sub_nonrefs	javax_imageio_stream_FileCacheImageInputStream;
};

// Object instance structure
struct _jc_javax_imageio_stream_FileCacheImageInputStream$object {
	_jc_javax_imageio_stream_FileCacheImageInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_stream_FileCacheImageInputStream$vtype	*vtype;
	_jc_javax_imageio_stream_FileCacheImageInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_stream_FileCacheImageInputStream$vtype _jc_javax_imageio_stream_FileCacheImageInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_stream_FileCacheImageInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_stream_FileCacheImageInputStream$class_object;

#endif	/* _JC_javax_imageio_stream_FileCacheImageInputStream_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/stream/FileCacheImageInputStream.h <==
// public class javax.imageio.stream.FileCacheImageInputStream

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e71a54dddda63520 javax_imageio_stream_FileCacheImageInputStream
// @dep_class 911ef4842ed4a340 javax_imageio_stream_ImageInputStreamImpl

// header file dependencies
// @dep_header javax_imageio_stream_ImageInputStreamImpl

#include "javax/imageio/stream/ImageInputStreamImpl.h"

#ifndef _JC_javax_imageio_stream_FileCacheImageInputStream_H_
#define _JC_javax_imageio_stream_FileCacheImageInputStream_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_stream_FileCacheImageInputStream$sub_refs	_jc_javax_imageio_stream_FileCacheImageInputStream$sub_refs;
typedef struct _jc_javax_imageio_stream_FileCacheImageInputStream$sub_nonrefs	_jc_javax_imageio_stream_FileCacheImageInputStream$sub_nonrefs;
typedef struct _jc_javax_imageio_stream_FileCacheImageInputStream$refs	_jc_javax_imageio_stream_FileCacheImageInputStream$refs;
typedef struct _jc_javax_imageio_stream_FileCacheImageInputStream$nonrefs	_jc_javax_imageio_stream_FileCacheImageInputStream$nonrefs;
typedef struct _jc_javax_imageio_stream_FileCacheImageInputStream$object	_jc_javax_imageio_stream_FileCacheImageInputStream$object;

typedef const struct _jc_javax_imageio_stream_FileCacheImageInputStream$vmethods	_jc_javax_imageio_stream_FileCacheImageInputStream$vmethods;
typedef const struct _jc_javax_imageio_stream_FileCacheImageInputStream$vtable	_jc_javax_imageio_stream_FileCacheImageInputStream$vtable;
typedef const struct _jc_javax_imageio_stream_FileCacheImageInputStream$vtype	_jc_javax_imageio_stream_FileCacheImageInputStream$vtype;

// Constructors
extern void _jc_javax_imageio_stream_FileCacheImageInputStream$method$_init$f95b7927140e2662(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_imageio_stream_FileCacheImageInputStream$method$checkStreamClosed$e73f603b18f58e4c(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_stream_FileCacheImageInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_imageio_stream_FileCacheImageInputStream$method$isCached$7eabc2d936c77133(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_imageio_stream_FileCacheImageInputStream$method$isCachedFile$ed19c4c24a1815db(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_imageio_stream_FileCacheImageInputStream$method$isCachedMemory$53b63747781a10df(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_stream_FileCacheImageInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_stream_FileCacheImageInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_stream_FileCacheImageInputStream$method_info$checkStreamClosed$e73f603b18f58e4c;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageInputStream$method_info$isCached$7eabc2d936c77133;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageInputStream$method_info$isCachedFile$ed19c4c24a1815db;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageInputStream$method_info$isCachedMemory$53b63747781a10df;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_javax_imageio_stream_FileCacheImageInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_javax_imageio_stream_FileCacheImageInputStream$vmethods {
	void	(*checkStreamClosed$e73f603b18f58e4c)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *) _JC_JCNI_ATTR;
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *) _JC_JCNI_ATTR;
	jboolean	(*isCached$7eabc2d936c77133)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *) _JC_JCNI_ATTR;
	jboolean	(*isCachedFile$ed19c4c24a1815db)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *) _JC_JCNI_ATTR;
	jboolean	(*isCachedMemory$53b63747781a10df)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_javax_imageio_stream_FileCacheImageInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_stream_FileCacheImageInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_stream_ImageInputStreamImpl$vmethods	javax_imageio_stream_ImageInputStreamImpl;
	_jc_javax_imageio_stream_FileCacheImageInputStream$vmethods	javax_imageio_stream_FileCacheImageInputStream;
};

// Vtype
struct _jc_javax_imageio_stream_FileCacheImageInputStream$vtype {
	_jc_type			type;
	_jc_javax_imageio_stream_FileCacheImageInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileCacheImageInputStream$sub_refs {
	struct _jc_java_io_InputStream$object	*stream;
	struct _jc_java_io_File$object	*cacheDir;
};

// Reference instance fields (object)
struct _jc_javax_imageio_stream_FileCacheImageInputStream$refs {
    _jc_javax_imageio_stream_FileCacheImageInputStream$sub_refs	javax_imageio_stream_FileCacheImageInputStream;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_refs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_stream_FileCacheImageInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_stream_FileCacheImageInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_stream_ImageInputStreamImpl$sub_nonrefs	javax_imageio_stream_ImageInputStreamImpl;
    _jc_javax_imageio_stream_FileCacheImageInputStream$sub_nonrefs	javax_imageio_stream_FileCacheImageInputStream;
};

// Object instance structure
struct _jc_javax_imageio_stream_FileCacheImageInputStream$object {
	_jc_javax_imageio_stream_FileCacheImageInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_stream_FileCacheImageInputStream$vtype	*vtype;
	_jc_javax_imageio_stream_FileCacheImageInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_stream_FileCacheImageInputStream$vtype _jc_javax_imageio_stream_FileCacheImageInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_stream_FileCacheImageInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_stream_FileCacheImageInputStream$class_object;

#endif	/* _JC_javax_imageio_stream_FileCacheImageInputStream_H_ */
